==> plank-player-5.27.11.tar.xz: plank-player-5.27.11/app/org.plank.player.desktop.cmake <==
[Desktop Entry]
Name=Plank Player
Name[ca]=Reproductor Plank
Name[ca@valencia]=Reproductor Plank
Name[cs]=Plank Player
Name[de]=Plank Player
Name[en_GB]=Plank Player
Name[eo]=Plank Player
Name[es]=Reproductor Plank
Name[eu]=Plank Jotzailea
Name[fi]=Plank Player
Name[fr]=Lecteur Plank
Name[gl]=Reprodutor Plank
Name[it]=Plank Player
Name[ka]=PlankPlayer
Name[ko]=Plank Player
Name[nl]=Plank-speler
Name[nn]=Plank Player
Name[pl]=Odtwarzacz Plank
Name[pt]=Leitor Plank
Name[pt_BR]=Plank Player
Name[ro]=Lector Plank
Name[ru]=Plank Player
Name[sl]=Plank Player
Name[sv]=Plank spelare
Name[tr]=Plank Oynatıcı
Name[uk]=Програвач Plank
Name[x-test]=xxPlank Playerxx
MimeType=@DesktopMimeType@
Exec=@DesktopExec@
Icon=plank-player
Type=Application
NoDisplay=@DesktopNoDisplay@
GenericName=PlankPlayer
GenericName[ca]=PlankPlayer
GenericName[ca@valencia]=PlankPlayer
GenericName[cs]=PlankPlayer
GenericName[de]=PlankPlayer
GenericName[en_GB]=PlankPlayer
GenericName[eo]=PlankLudilo
GenericName[es]=PlankPlayer
GenericName[eu]=Plank jotzailea
GenericName[fi]=PlankPlayer
GenericName[fr]=Lecteur Plank
GenericName[gl]=PlankPlayer
GenericName[hi]=प्लॅन्क-प्लॅयर
GenericName[hu]=PlankPlayer
GenericName[it]=PlankPlayer
GenericName[ka]=PlankPlayer
GenericName[ko]=PlankPlayer
GenericName[nl]=PlankPlayer
GenericName[nn]=PlankPlayer
GenericName[pl]=Odtwarzacz Plank
GenericName[pt]=Leitor Plank
GenericName[pt_BR]=PlankPlayer
GenericName[ro]=PlankPlayer
GenericName[ru]=PlankPlayer
GenericName[sk]=PlankPlayer
GenericName[sl]=PlankPlayer
GenericName[sv]=PlankPlayer
GenericName[tr]=Plank Oynatıcı
GenericName[uk]=PlankPlayer
GenericName[x-test]=xxPlankPlayerxx
GenericName[zh_CN]=PlankPlayer
Categories=AudioVideo;Player;
Keywords=program;multimedia;Player;
Keywords[ca]=programa;multimedia;reproductor;
Keywords[ca@valencia]=programa;multimedia;reproductor;
Keywords[cs]=program;multimédia;přehrávač;
Keywords[de]=medien;spieler;
Keywords[en_GB]=program;multimedia;Player;
Keywords[eo]=programo;plurmedia;Ludilo;
Keywords[es]=programa;multimedia;Reproductor;
Keywords[eu]=programa;multimedia;Player;Jotzailea;
Keywords[fi]=ohjelma;multimedia;soitin;
Keywords[fr]=programme ; multimédia ; lecteur ;
Keywords[gl]=programa;multimedia;reprodutor;
Keywords[hi]=कार्यक्रम;मल्टीमीडिया;प्लॅयर;
Keywords[hu]=program;multimédia;Lejátszó;
Keywords[it]=programma;multimedia;lettore;
Keywords[ka]=პროგრამა;მულტიმედია;დამკვრელი;
Keywords[ko]=program;multimedia;Player;프로그램;멀티미디어;재생기;
Keywords[nl]=programma;multimedia;afspeler;
Keywords[nn]=program;multimedia;spelar;
Keywords[pl]=program;multimedia;odtwarzacz;
Keywords[pt]=programa;multimédia;Leitor;
Keywords[pt_BR]=programa;multimídia;reprodutor;tocador;
Keywords[ro]=program;multimedia;lector;
Keywords[ru]=program;multimedia;Player;программа;мультимедиа;проигрыватель;
Keywords[sk]=program;multimédiá;prehrávač;
Keywords[sl]=program;multimedija;Predvajalnik;
Keywords[sv]=program;multimedia;spelare;
Keywords[tr]=program;çoklu ortam;oynatıcı;
Keywords[uk]=program;multimedia;Player;програма;мультимедіа;звук;відео;програвач;
Keywords[x-test]=xxprogramxx;xxmultimediaxx;xxPlayerxx;
Keywords[zh_CN]=program;multimedia;Player;程序;多媒体;播放器;chengxu;duomeiti;bofangqi;

==> plank-player-5.27.12.tar.xz: plank-player-5.27.12/app/org.plank.player.desktop.cmake <==
[Desktop Entry]
Name=Plank Player
Name[ar]=مشغل بلانك
Name[ca]=Reproductor Plank
Name[ca@valencia]=Reproductor Plank
Name[cs]=Plank Player
Name[de]=Plank Player
Name[en_GB]=Plank Player
Name[eo]=Plank Player
Name[es]=Reproductor Plank
Name[eu]=Plank Jotzailea
Name[fi]=Plank Player
Name[fr]=Lecteur Plank
Name[gl]=Reprodutor Plank
Name[it]=Plank Player
Name[ka]=PlankPlayer
Name[ko]=Plank Player
Name[nl]=Plank-speler
Name[nn]=Plank Player
Name[pl]=Odtwarzacz Plank
Name[pt]=Leitor Plank
Name[pt_BR]=Plank Player
Name[ro]=Lector Plank
Name[ru]=Plank Player
Name[sk]=Prehrávač Plank
Name[sl]=Plank Player
Name[sv]=Plank spelare
Name[tr]=Plank Oynatıcı
Name[uk]=Програвач Plank
Name[x-test]=xxPlank Playerxx
MimeType=@DesktopMimeType@
Exec=@DesktopExec@
Icon=plank-player
Type=Application
NoDisplay=@DesktopNoDisplay@
GenericName=PlankPlayer
GenericName[ar]=مشغل بلانك
GenericName[ca]=PlankPlayer
GenericName[ca@valencia]=PlankPlayer
GenericName[cs]=PlankPlayer
GenericName[de]=PlankPlayer
GenericName[en_GB]=PlankPlayer
GenericName[eo]=PlankLudilo
GenericName[es]=PlankPlayer
GenericName[eu]=Plank jotzailea
GenericName[fi]=PlankPlayer
GenericName[fr]=Lecteur Plank
GenericName[gl]=PlankPlayer
GenericName[hi]=प्लॅन्क-प्लॅयर
GenericName[hu]=PlankPlayer
GenericName[it]=PlankPlayer
GenericName[ka]=PlankPlayer
GenericName[ko]=PlankPlayer
GenericName[nl]=PlankPlayer
GenericName[nn]=PlankPlayer
GenericName[pl]=Odtwarzacz Plank
GenericName[pt]=Leitor Plank
GenericName[pt_BR]=PlankPlayer
GenericName[ro]=PlankPlayer
GenericName[ru]=PlankPlayer
GenericName[sk]=PlankPlayer
GenericName[sl]=PlankPlayer
GenericName[sv]=PlankPlayer
GenericName[tr]=Plank Oynatıcı
GenericName[uk]=PlankPlayer
GenericName[x-test]=xxPlankPlayerxx
GenericName[zh_CN]=PlankPlayer
Categories=AudioVideo;Player;
Keywords=program;multimedia;Player;
Keywords[ar]=برنامج;الوسائط المتعددة;مشغل;
Keywords[ca]=programa;multimedia;reproductor;
Keywords[ca@valencia]=programa;multimedia;reproductor;
Keywords[cs]=program;multimédia;přehrávač;
Keywords[de]=medien;spieler;
Keywords[en_GB]=program;multimedia;Player;
Keywords[eo]=programo;plurmedia;Ludilo;
Keywords[es]=programa;multimedia;Reproductor;
Keywords[eu]=programa;multimedia;Player;Jotzailea;
Keywords[fi]=ohjelma;multimedia;soitin;
Keywords[fr]=programme ; multimédia ; lecteur ;
Keywords[gl]=programa;multimedia;reprodutor;
Keywords[hi]=कार्यक्रम;मल्टीमीडिया;प्लॅयर;
Keywords[hu]=program;multimédia;Lejátszó;
Keywords[id]=program;multimedia;Pemutar;
Keywords[it]=programma;multimedia;lettore;
Keywords[ka]=პროგრამა;მულტიმედია;დამკვრელი;
Keywords[ko]=program;multimedia;Player;프로그램;멀티미디어;재생기;
Keywords[nl]=programma;multimedia;afspeler;
Keywords[nn]=program;multimedia;spelar;
Keywords[pl]=program;multimedia;odtwarzacz;
Keywords[pt]=programa;multimédia;Leitor;
Keywords[pt_BR]=programa;multimídia;reprodutor;tocador;
Keywords[ro]=program;multimedia;lector;
Keywords[ru]=program;multimedia;Player;программа;мультимедиа;проигрыватель;
Keywords[sk]=program;multimédiá;prehrávač;
Keywords[sl]=program;multimedija;Predvajalnik;
Keywords[sv]=program;multimedia;spelare;
Keywords[tr]=program;çoklu ortam;oynatıcı;
Keywords[uk]=program;multimedia;Player;програма;мультимедіа;звук;відео;програвач;
Keywords[x-test]=xxprogramxx;xxmultimediaxx;xxPlayerxx;
Keywords[zh_CN]=program;multimedia;Player;程序;多媒体;播放器;chengxu;duomeiti;bofangqi;
